==> fly-qdm_2.6.0.tar.xz: fly-qdm/dm_greet_winbind/fly-dmgreet_winbind_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name></name>
    <message>
        <source>Winbind / Samba</source>
        <translation type="vanished">Winbind / Samba</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>Winbind / Samba</source>
        <translation type="obsolete">Winbind / Samba</translation>
    </message>
</context>
<context>
    <name>KWinbindGreeter</name>
    <message>
        <source>&amp;Domain:</source>
        <translation>&amp;Домен:</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Имя:</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Домен:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Пароль:</translation>
    </message>
    <message>
        <source>Current &amp;password:</source>
        <translation>&amp;Текущий пароль:</translation>
    </message>
    <message>
        <source>&amp;New password:</source>
        <translation>&amp;Новый пароль:</translation>
    </message>
    <message>
        <source>Con&amp;firm password:</source>
        <translation>П&amp;одтвердите пароль:</translation>
    </message>
    <message>
        <source>Unrecognized prompt &quot;%1&quot;</source>
        <translation>Нераспознанное приглашение на ввод &quot;%1&quot;</translation>
    </message>
    <message>
        <source>\b(old|current)\b</source>
        <translation type="vanished">(стар|предыд)</translation>
    </message>
    <message>
        <source>\b(re-?(enter|type)|again|confirm|repeat)\b</source>
        <translation type="vanished">(снова|опять|подтверд|повтор)</translation>
    </message>
    <message>
        <source>\bnew\b</source>
        <translation>нов</translation>
    </message>
    <message>
        <source>\bpassword\b</source>
        <translation>парол</translation>
    </message>
    <message>
        <source>\b(re-?(enter|type)|re?(enter|type)|again|confirm|repeat)\b</source>
        <translation>(снова|опять|подтверд|повтор|ещё раз|еще раз)</translation>
    </message>
</context>
</TS>

==> fly-qdm_2.9.6.tar.xz: fly-qdm/dm_greet_winbind/fly-dmgreet_winbind_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name></name>
    <message>
        <source>Winbind / Samba</source>
        <translation type="vanished">Winbind / Samba</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>Winbind / Samba</source>
        <translation type="obsolete">Winbind / Samba</translation>
    </message>
</context>
<context>
    <name>KWinbindGreeter</name>
    <message>
        <source>&amp;Domain:</source>
        <translation>&amp;Домен:</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Имя:</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Домен:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Пароль:</translation>
    </message>
    <message>
        <source>Current &amp;password:</source>
        <translation>&amp;Текущий пароль:</translation>
    </message>
    <message>
        <source>&amp;New password:</source>
        <translation>&amp;Новый пароль:</translation>
    </message>
    <message>
        <source>Con&amp;firm password:</source>
        <translation>П&amp;одтвердите пароль:</translation>
    </message>
    <message>
        <source>Unrecognized prompt &quot;%1&quot;</source>
        <translation>Нераспознанное приглашение на ввод &quot;%1&quot;</translation>
    </message>
    <message>
        <source>\b(old|current)\b</source>
        <translation type="vanished">(стар|предыд)</translation>
    </message>
    <message>
        <source>\b(re-?(enter|type)|again|confirm|repeat)\b</source>
        <translation type="vanished">(снова|опять|подтверд|повтор)</translation>
    </message>
    <message>
        <source>\bnew\b</source>
        <translation>нов</translation>
    </message>
    <message>
        <source>\bpassword\b</source>
        <translation>парол</translation>
    </message>
    <message>
        <source>\b(re-?(enter|type)|re?(enter|type)|again|confirm|repeat)\b</source>
        <translation type="vanished">(снова|опять|подтверд|повтор|ещё раз|еще раз)</translation>
    </message>
    <message>
        <source>\bPIN\b</source>
        <translation>ПИН</translation>
    </message>
    <message>
        <source>\b(re-?(enter|type)|re?(enter|type)|again|confirm|repeat|supply)\b</source>
        <translation>(снова|опять|подтверд|повтор|ещё раз|еще раз|предост)</translation>
    </message>
    <message>
        <source>&amp;PIN:</source>
        <translation>&amp;ПИН:</translation>
    </message>
    <message>
        <source>Current &amp;pin:</source>
        <translation>Текущий &amp;ПИН:</translation>
    </message>
    <message>
        <source>&amp;New pin:</source>
        <translation>&amp;Новый ПИН:</translation>
    </message>
    <message>
        <source>Con&amp;firm pin:</source>
        <translation>П&amp;одтвердите ПИН:</translation>
    </message>
</context>
</TS>
